From mboxrd@z Thu Jan  1 00:00:00 1970
From: Klemens Nanni <klemens@posteo.de>
To: list+catgirl@causal.agency
Cc: Klemens Nanni <klemens@posteo.de>
Subject: [PATCH 1/3] Hoist loading default root certificates into ircConfig()
Date: Thu, 10 Jun 2021 01:32:09 +0000
Message-Id: <20210610013211.91477-1-klemens@posteo.de>
MIME-Version: 1.0
Content-Transfer-Encoding: 8bit

tls_connect_socket(3) in ircConnect() does that by default already
unless tls_load_file(3)/tls_config_set_ca_mem(3) was used.

Loading CA certificates before connecting makes no practical difference
except on OpenBSD where this allows for tighter unveil und pledge setups
now that all required (TLS related) file I/O is finished by the time
ircConnect() gets to do network I/O.

In case of the hidden `-!' insecure flag which is implied by `-o' to
print server certificates and exit, loading root certificates is not
required at all;  likewise, using explicit self signed server
certificates will not involve certificate authorities either, hence load
them only if needed.
---
 irc.c | 9 +++++++++
 1 file changed, 9 insertions(+)

diff --git a/irc.c b/irc.c
index c98193a..92a70fe 100644
--- a/irc.c
+++ b/irc.c
@@ -71,6 +71,15 @@ void ircConfig(
 		if (error) errx(EX_NOINPUT, "%s: %s", trust, tls_config_error(config));
 	}
 
+	if (!insecure && !trust) {
+		size_t ca_sz;
+		uint8_t *ca = tls_load_file(tls_default_ca_cert_file(), &ca_sz, NULL);
+		if (!ca) errx(EX_SOFTWARE, "tls_load_file");
+		error = tls_config_set_ca_mem(config, ca, ca_sz);
+		if (error == -1) errx(EX_SOFTWARE, "tls_config_set_ca_mem");
+		tls_unload_file(ca, ca_sz);
+	}
+
 	if (cert) {
 		const char *dirs = NULL;
 		for (const char *path; NULL != (path = configPath(&dirs, cert));) {
-- 
2.32.0


